==> dnet-openaireplus-workflows-0.0.1-20140124.100305-192-sources.jar: eu/dnetlib/msro/openaireplus/workflows/nodes/UpdateRepositoryProfilesJobNode.java <==
package eu.dnetlib.msro.openaireplus.workflows.nodes;

import java.io.StringReader;
import java.util.Map;

import javax.annotation.Resource;
import javax.xml.ws.wsaddressing.W3CEndpointReference;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.dom4j.Document;
import org.dom4j.io.SAXReader;

import com.googlecode.sarasvati.Arc;
import com.googlecode.sarasvati.NodeToken;

import eu.dnetlib.enabling.datasources.DatasourceFunctions;
import eu.dnetlib.enabling.is.registry.rmi.ISRegistryService;
import eu.dnetlib.enabling.resultset.client.ResultSetClientFactory;
import eu.dnetlib.enabling.tools.ServiceLocator;
import eu.dnetlib.msro.openaireplus.workflows.nodes.FindExistingRepositoriesJobNode.RepositoryInfo;
import eu.dnetlib.msro.workflows.nodes.ProgressJobNode;
import eu.dnetlib.msro.workflows.nodes.SimpleJobNode;
import eu.dnetlib.msro.workflows.resultset.ProcessCountingResultSetFactory;
import eu.dnetlib.msro.workflows.util.ProgressProvider;
import eu.dnetlib.msro.workflows.util.ResultsetProgressProvider;
import eu.dnetlib.msro.workflows.util.WorkflowsConstants;

public class UpdateRepositoryProfilesJobNode extends SimpleJobNode implements ProgressJobNode {

	private static final String REPOSITORY_SERVICE_RESOURCE_TYPE = "RepositoryServiceResourceType";

	@Resource
	private ResultSetClientFactory resultSetClientFactory;

	@Resource(name = "registryLocator")
	private ServiceLocator<ISRegistryService> registryLocator;

	@Resource
	private ProcessCountingResultSetFactory processCountingResultSetFactory;

	private String eprParam = "repoEpr";
	private String existingReposParam = "existingRepos";
	private ResultsetProgressProvider progressProvider;

	private static final Log log = LogFactory.getLog(UpdateRepositoryProfilesJobNode.class); // NOPMD by marko on 11/24/08 5:02 PM

	@Override
	protected String execute(final NodeToken token) throws Exception {
		// datasourceID -> profileID
		@SuppressWarnings("unchecked")
		final Map<String, RepositoryInfo> existingRepos = (Map<String, RepositoryInfo>) token.getFullEnv().getTransientAttribute(getExistingReposParam());
		final W3CEndpointReference epr = (W3CEndpointReference) token.getFullEnv().getTransientAttribute(getEprParam());

		this.progressProvider = processCountingResultSetFactory.createProgressProvider(token.getProcess(), epr);

		final SAXReader reader = new SAXReader();

		int countUpdated = 0;
		int countInserted = 0;
		int countProfileErrors = 0;
		int countErrorsWithActiveInterfaces = 0;

		log.info("Adding/updating repository profiles...");
		for (String profile : resultSetClientFactory.getClient(this.progressProvider.getEpr())) {
			try {
				final Document doc = reader.read(new StringReader(profile));
				final String dsId = doc.valueOf("//EXTRA_FIELDS/FIELD[./key='OpenAireDataSourceId']/value");
				final int nActiveInterfaces = doc.selectNodes("//INTERFACE[@active='true']").size();

				log.debug("Registering/updating profile:\n " + profile + "\n");

				if (existingRepos.containsKey(dsId)) {
					final RepositoryInfo info = existingRepos.get(dsId);
					doc.selectSingleNode("//RESOURCE_IDENTIFIER/@value").setText(info.repoId);
					doc.selectSingleNode("//RESOURCE_KIND/@value").setText(info.resourceKind);
					registryLocator.getService().updateProfile(info.repoId, doc.asXML(), REPOSITORY_SERVICE_RESOURCE_TYPE);
					log.debug("Profile " + info.repoId + " UPDATED for ds " + dsId);
					countUpdated++;

					if (DatasourceFunctions.verifyCompliance(doc) && info.resourceKind.equals("PendingRepositoryResources")) {
						registryLocator.getService().validateProfile(info.repoId);
					}

					if (!DatasourceFunctions.verifyCompliance(doc) && info.resourceKind.equals("RepositoryServiceResources")) {
						if (nActiveInterfaces == 0) {
							registryLocator.getService().invalidateProfile(info.repoId);
						} else {
							countErrorsWithActiveInterfaces++;
						}
					}

				} else {
					if (DatasourceFunctions.verifyCompliance(doc) || (nActiveInterfaces > 0)) {
						final String profId = registryLocator.getService().registerProfile(doc.asXML());
						log.debug("Valid Profile " + profId + " REGISTERED for ds " + dsId);
						if (!DatasourceFunctions.verifyCompliance(doc)) {
							countErrorsWithActiveInterfaces++;
						}
					} else {
						final String profId = registryLocator.getService().insertProfileForValidation(REPOSITORY_SERVICE_RESOURCE_TYPE, doc.asXML());
						log.debug("Pending Profile " + profId + " REGISTERED for ds " + dsId);
					}
					countInserted++;
				}
			} catch (Exception e) {
				log.error("INVALID PROFILE: " + profile, e);
				countProfileErrors++;
			}
		}

		log.info("   - updated_profiles: " + countUpdated);
		log.info("   - inserted_profiles: " + countInserted);
		log.info("   - profiles_with_errors: " + countProfileErrors);
		log.info("   - invalidCompatibilityLevelForDsWithActiveInterfaces: " + countErrorsWithActiveInterfaces);

		token.getEnv().setAttribute(WorkflowsConstants.MAIN_LOG_PREFIX + "updated_profiles", countUpdated);
		token.getEnv().setAttribute(WorkflowsConstants.MAIN_LOG_PREFIX + "inserted_profiles", countInserted);
		token.getEnv().setAttribute(WorkflowsConstants.MAIN_LOG_PREFIX + "profiles_with_errors", countProfileErrors);
		token.getEnv().setAttribute(WorkflowsConstants.MAIN_LOG_PREFIX + "invalidCompatibilityLevelForDsWithActiveInterfaces", countErrorsWithActiveInterfaces);
		return Arc.DEFAULT_ARC;
	}

	public String getEprParam() {
		return eprParam;
	}

	public void setEprParam(final String eprParam) {
		this.eprParam = eprParam;
	}

	public String getExistingReposParam() {
		return existingReposParam;
	}

	public void setExistingReposParam(final String existingReposParam) {
		this.existingReposParam = existingReposParam;
	}

	@Override
	public ProgressProvider getProgressProvider() {
		return progressProvider;
	}

}

==> dnet-openaireplus-workflows-2.0.1-20141114.113430-1-sources.jar: eu/dnetlib/msro/openaireplus/workflows/nodes/UpdateRepositoryProfilesJobNode.java <==
package eu.dnetlib.msro.openaireplus.workflows.nodes;

import java.io.StringReader;
import java.util.Map;

import javax.annotation.Resource;
import javax.xml.ws.wsaddressing.W3CEndpointReference;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.dom4j.Document;
import org.dom4j.io.SAXReader;

import com.googlecode.sarasvati.Arc;
import com.googlecode.sarasvati.NodeToken;

import eu.dnetlib.enabling.datasources.DatasourceFunctions;
import eu.dnetlib.enabling.is.registry.rmi.ISRegistryService;
import eu.dnetlib.enabling.locators.UniqueServiceLocator;
import eu.dnetlib.enabling.resultset.client.ResultSetClientFactory;
import eu.dnetlib.msro.openaireplus.workflows.nodes.FindExistingRepositoriesJobNode.RepositoryInfo;
import eu.dnetlib.msro.workflows.nodes.ProgressJobNode;
import eu.dnetlib.msro.workflows.nodes.SimpleJobNode;
import eu.dnetlib.msro.workflows.resultset.ProcessCountingResultSetFactory;
import eu.dnetlib.msro.workflows.util.ProgressProvider;
import eu.dnetlib.msro.workflows.util.ResultsetProgressProvider;
import eu.dnetlib.msro.workflows.util.WorkflowsConstants;

public class UpdateRepositoryProfilesJobNode extends SimpleJobNode implements ProgressJobNode {

	private static final String REPOSITORY_SERVICE_RESOURCE_TYPE = "RepositoryServiceResourceType";

	@Resource
	private ResultSetClientFactory resultSetClientFactory;

	@Resource
	private UniqueServiceLocator serviceLocator;

	@Resource
	private ProcessCountingResultSetFactory processCountingResultSetFactory;

	private String eprParam = "repoEpr";
	private String existingReposParam = "existingRepos";
	private ResultsetProgressProvider progressProvider;

	private static final Log log = LogFactory.getLog(UpdateRepositoryProfilesJobNode.class); // NOPMD by marko on 11/24/08 5:02 PM

	@Override
	protected String execute(final NodeToken token) throws Exception {
		// datasourceID -> profileID
		@SuppressWarnings("unchecked")
		final Map<String, RepositoryInfo> existingRepos = (Map<String, RepositoryInfo>) token.getFullEnv().getTransientAttribute(getExistingReposParam());
		final W3CEndpointReference epr = (W3CEndpointReference) token.getFullEnv().getTransientAttribute(getEprParam());

		this.progressProvider = processCountingResultSetFactory.createProgressProvider(token.getProcess(), epr);

		final SAXReader reader = new SAXReader();

		int countUpdated = 0;
		int countInserted = 0;
		int countProfileErrors = 0;
		int countErrorsWithActiveInterfaces = 0;

		log.info("Adding/updating repository profiles...");

		final ISRegistryService registry = serviceLocator.getService(ISRegistryService.class);

		for (String profile : resultSetClientFactory.getClient(this.progressProvider.getEpr())) {
			try {
				final Document doc = reader.read(new StringReader(profile));
				final String dsId = doc.valueOf("//EXTRA_FIELDS/FIELD[./key='OpenAireDataSourceId']/value");
				final int nActiveInterfaces = doc.selectNodes("//INTERFACE[@active='true']").size();

				log.debug("Registering/updating profile:\n " + profile + "\n");

				if (existingRepos.containsKey(dsId)) {
					final RepositoryInfo info = existingRepos.get(dsId);
					doc.selectSingleNode("//RESOURCE_IDENTIFIER/@value").setText(info.repoId);
					doc.selectSingleNode("//RESOURCE_KIND/@value").setText(info.resourceKind);
					registry.updateProfile(info.repoId, doc.asXML(), REPOSITORY_SERVICE_RESOURCE_TYPE);
					log.debug("Profile " + info.repoId + " UPDATED for ds " + dsId);
					countUpdated++;

					if (DatasourceFunctions.verifyCompliance(doc) && info.resourceKind.equals("PendingRepositoryResources")) {
						registry.validateProfile(info.repoId);
					}

					if (!DatasourceFunctions.verifyCompliance(doc) && info.resourceKind.equals("RepositoryServiceResources")) {
						if (nActiveInterfaces == 0) {
							registry.invalidateProfile(info.repoId);
						} else {
							countErrorsWithActiveInterfaces++;
						}
					}

				} else {
					if (DatasourceFunctions.verifyCompliance(doc) || nActiveInterfaces > 0) {
						final String profId = registry.registerProfile(doc.asXML());
						log.debug("Valid Profile " + profId + " REGISTERED for ds " + dsId);
						if (!DatasourceFunctions.verifyCompliance(doc)) {
							countErrorsWithActiveInterfaces++;
						}
					} else {
						final String profId = registry.insertProfileForValidation(REPOSITORY_SERVICE_RESOURCE_TYPE, doc.asXML());
						log.debug("Pending Profile " + profId + " REGISTERED for ds " + dsId);
					}
					countInserted++;
				}
			} catch (Exception e) {
				log.error("INVALID PROFILE: " + profile, e);
				countProfileErrors++;
			}
		}

		log.info("   - updated_profiles: " + countUpdated);
		log.info("   - inserted_profiles: " + countInserted);
		log.info("   - profiles_with_errors: " + countProfileErrors);
		log.info("   - invalidCompatibilityLevelForDsWithActiveInterfaces: " + countErrorsWithActiveInterfaces);

		token.getEnv().setAttribute(WorkflowsConstants.MAIN_LOG_PREFIX + "updated_profiles", countUpdated);
		token.getEnv().setAttribute(WorkflowsConstants.MAIN_LOG_PREFIX + "inserted_profiles", countInserted);
		token.getEnv().setAttribute(WorkflowsConstants.MAIN_LOG_PREFIX + "profiles_with_errors", countProfileErrors);
		token.getEnv().setAttribute(WorkflowsConstants.MAIN_LOG_PREFIX + "invalidCompatibilityLevelForDsWithActiveInterfaces", countErrorsWithActiveInterfaces);
		return Arc.DEFAULT_ARC;
	}

	public String getEprParam() {
		return eprParam;
	}

	public void setEprParam(final String eprParam) {
		this.eprParam = eprParam;
	}

	public String getExistingReposParam() {
		return existingReposParam;
	}

	public void setExistingReposParam(final String existingReposParam) {
		this.existingReposParam = existingReposParam;
	}

	@Override
	public ProgressProvider getProgressProvider() {
		return progressProvider;
	}

}
